@@ -35,6 +35,15 @@ pub type Frm = Framed<protwrap::tokio::Stream, blather::Codec>;
 /// will fail.  To be able to keep the connection up in case the authentication
 /// fails, pass `None` to the `auth` argument and manually authenticate in the
 /// application.
+///
+/// # Examples
+/// ```no_run
+/// use ddmw_client::conn;
+/// async fn test() {
+///   let pa = protwrap::ProtAddr::Tcp("127.0.0.1:8777".to_string());
+///   let conn = conn::connect(&pa, None).await.expect("Unable to connect");
+/// }
+/// ```
 pub async fn connect(
   pa: &ProtAddr,
   auth: Option<&Auth>
@@ -54,10 +63,13 @@ pub async fn connect(
 /// Send a telegram then wait for and return the server's reply.
 /// If the server returns a `Fail`, it will be returned as
 /// `Err(Error::ServerError)`.
-pub async fn sendrecv<T: AsyncRead + AsyncWrite + Unpin>(
+pub async fn sendrecv<T>(
   conn: &mut Framed<T, blather::Codec>,
   tg: &Telegram
-) -> Result<blather::Params, Error> {
+) -> Result<blather::Params, Error>
+where
+  T: AsyncRead + AsyncWrite + Unpin
+{
   conn.send(tg).await?;
   expect_okfail(conn).await
 }
@@ -66,9 +78,12 @@ pub async fn sendrecv<T: AsyncRead + AsyncWrite + Unpin>(
 /// Waits for a message and ensures that it's Ok or Fail.
 /// Converts Fail state to an Error::ServerError.
 /// Returns a Params buffer containig the Ok parameters on success.
-pub async fn expect_okfail<T: AsyncRead + AsyncWrite + Unpin>(
+pub async fn expect_okfail<T>(
   conn: &mut Framed<T, blather::Codec>
-) -> Result<blather::Params, Error> {
+) -> Result<blather::Params, Error>
+where
+  T: AsyncRead + Unpin
+{
   if let Some(o) = conn.next().await {
     let o = o?;
     match o {
@@ -99,9 +114,29 @@ pub struct WhoAmI {
 }
 
 /// Return the current owner of a connection.
-pub async fn whoami<T: AsyncRead + AsyncWrite + Unpin>(
+///
+/// # Examples
+/// ```no_run
+/// use ddmw_client::{conn, auth};
+/// async fn test() {
+///   let pa = protwrap::ProtAddr::Tcp("127.0.0.1:8777".to_string());
+///   let auth = auth::Builder::new()
+///     .name("elena")
+///     .pass("secret")
+///     .build().expect("Unable to build Auth buffer");
+///   let mut frm = conn::connect(&pa, Some(&auth)).await
+///     .expect("Connection failed");
+///
+///   let w = conn::whoami(&mut frm).await.expect("whoami failed");
+///   assert_eq!(&w.name, "elena");
+/// }
+/// ```
+pub async fn whoami<T>(
   conn: &mut Framed<T, blather::Codec>
-) -> Result<WhoAmI, Error> {
+) -> Result<WhoAmI, Error>
+where
+  T: AsyncRead + AsyncWrite + Unpin
+{
   let tg = Telegram::new_topic("WhoAmI")?;
   let params = sendrecv(conn, &tg).await?;
   let id = params.get_param::<i64>("Id")?;
