@@ -528,12 +528,12 @@ pub trait Handler {
   /// Called once a message header has been received to allow the application
   /// to choose how to store the meta and payload content.
   async fn on_header(
-    &self,
+    &mut self,
     mi: &MsgInfo
   ) -> Result<(StoreType, StoreType), Error>;
 
   /// Called once the metadata and payload have been received.
-  async fn on_data(&self, msg: Msg) -> Result<(), Error>;
+  async fn on_data(&mut self, msg: Msg) -> Result<(), Error>;
 }
 
 
@@ -545,7 +545,7 @@ pub trait Handler {
 /// to store the message's metadata and payload content.
 pub async fn recv_h<C>(
   conn: &mut Framed<C, blather::Codec>,
-  handler: &Box<dyn Handler + Send + Sync>
+  handler: &mut Box<dyn Handler + Send + Sync>
 ) -> Result<Msg, Error>
 where
   C: AsyncRead + AsyncWrite + Unpin
@@ -612,7 +612,7 @@ fn parse_header(mp: &Params) -> Result<(u32, u32, u64), Error> {
 async fn proc_inbound_msg_h<C>(
   conn: &mut Framed<C, blather::Codec>,
   mp: Params,
-  handler: &Box<dyn Handler + Send + Sync>
+  handler: &mut Box<dyn Handler + Send + Sync>
 ) -> Result<Msg, Error>
 where
   C: AsyncRead + AsyncWrite + Unpin
@@ -691,7 +691,7 @@ where
 /// #[async_trait]
 /// impl Handler for RecvProc {
 ///   async fn on_header(
-///     &self,
+///     &mut self,
 ///     mi: &MsgInfo
 ///   ) -> Result<(StoreType, StoreType), ddmw_client::Error> {
 ///     // A new message is arriving; give the application the opportunity
@@ -722,7 +722,7 @@ where
 ///     Ok((meta_store, payload_store))
 ///   }
 ///
-///   async fn on_data(&self, msg: Msg) -> Result<(), ddmw_client::Error> {
+///   async fn on_data(&mut self, msg: Msg) -> Result<(), ddmw_client::Error> {
 ///     println!("Process message");
 ///
 ///     // ToDo: Do things with message buffer here
@@ -738,17 +738,17 @@ where
 ///   let subinfo = SubInfo { ch: SubCh::Num(11) };
 ///   ddmw_client::msg::recv::subscribe(&mut conn, subinfo).await.unwrap();
 ///
-///   let handler = Box::new(RecvProc { idx: 0 })
+///   let mut handler = Box::new(RecvProc { idx: 0 })
 ///       as Box<dyn Handler + Sync + Send>;
 ///
-///   msg::recvloop_h(&mut conn, None, &handler).await.unwrap();
+///   msg::recvloop_h(&mut conn, None, &mut handler).await.unwrap();
 /// }
 /// ```
 // ToDo: yield, when it becomes available
 pub async fn recvloop_h<C>(
   conn: &mut Framed<C, blather::Codec>,
   kill: Option<killswitch::Shutdown>,
-  handler: &Box<dyn Handler + Send + Sync>
+  handler: &mut Box<dyn Handler + Send + Sync>
 ) -> Result<(), Error>
 where
   C: AsyncRead + AsyncWrite + Unpin
